#include "MyGLWidget.hpp"

MyGLWidget::MyGLWidget(QWidget *parent)
    : QGLWidget(parent)
{
    startTimer(15); // shooting for 60 FPS
}

MyGLWidget::~MyGLWidget()
{
}

QSize MyGLWidget::minimumSizeHint() const
{
    return QSize(640, 640);
}

QSize MyGLWidget::sizeHint() const
{
    return QSize(800, 800);
}

void MyGLWidget::initializeGL()
{
    // Orthographic projection
    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
    glOrtho(-3, 3, 3, -3, -4, 15);

    // Enable smooth color gradients between vertices
    glShadeModel(GL_SMOOTH);

    // Identity modelview
    glMatrixMode(GL_MODELVIEW);
    glLoadIdentity();

    // Background color is black
    glClearColor(0.0f, 0.0f, 0.0f, 0.0f);

    // Enable the depth test to cause faces to render from back to front
    glEnable(GL_DEPTH_TEST);
    glDepthFunc(GL_LEQUAL);

    // Use the nicest perspective correction hint
    glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);

    // Enable cull face so faces with normals pointing away from the camera
    // do not get rendered
    glEnable(GL_CULL_FACE);

    angle = 0.0f;
}

void MyGLWidget::paintGL()
{
    // Clear color (background) and depth (for depth test) buffers
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

    glMatrixMode(GL_MODELVIEW);

    glLoadIdentity();
    glRotatef(30.0f, 0, 1, 0);
    glRotatef(angle, 0, 0, 1);

    glTranslatef(-1.5f, 0.0f, 0.0f);

    cube.draw();

    glTranslatef(3.0f, 0.0f, 0.0f);

    cube.draw();
}

void MyGLWidget::timerEvent(QTimerEvent *)
{
    angle += 1.0f; // degrees

    // Redraw on a timer
    update();
}

void MyGLWidget::resizeGL(int width, int height)
{
    // Fix viewport to new size
    glViewport(0, 0, width, height);
}

void MyGLWidget::mousePressEvent(QMouseEvent *event)
{
}

void MyGLWidget::mouseMoveEvent(QMouseEvent *event)
{
}
